{% load i18n %}
<th scope="col" class="{{ class_attrib }}">
  {% if sorted_fields %}
    <div class="sortoptions">
      <a href="{{ url }}"
         class="toggle glyphicon glyphicon-chevron-{% if ascending %}up{% else %}down{% endif %}"
	       title="{% trans 'Toggle sorting' %}">
      </a>
    </div>
  {% endif %}
  <div class="text">
    <a href="{{ url }}">{{ text }}</a>
  </div>
  <div class="clear"></div>
</th>
